@@ -21,7 +21,8 @@ features:
 
     schema = model.parse_feature_schema(schema_text)
     vector = schema.gen_trip_vector(model.RawInput(
-        start_time=datetime.datetime.fromisoformat("2020-04-29 16:00:00").timestamp(),
+        start_time=datetime.datetime.fromisoformat(
+            "2020-04-29 16:00:00+00:00").timestamp(),
         pickup_lat=1.033333,
         pickup_lng=103.111111,
         dropoff_lat=1.044444,
